==> ec2-0.9.0-sources.jar: software/amazon/awscdk/services/ec2/cloudformation/VPCEndpointServicePermissionsResourceProps.java <==
package software.amazon.awscdk.services.ec2.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:56:33.426Z")
public interface VPCEndpointServicePermissionsResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
     */
    java.lang.Object getServiceId();
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
     */
    void setServiceId(final java.lang.String value);
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
     */
    void setServiceId(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
     */
    java.lang.Object getAllowedPrincipals();
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
     */
    void setAllowedPrincipals(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
     */
    void setAllowedPrincipals(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link VPCEndpointServicePermissionsResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link VPCEndpointServicePermissionsResourceProps}
     */
    final class Builder {
        private java.lang.Object _serviceId;
        @javax.annotation.Nullable
        private java.lang.Object _allowedPrincipals;

        /**
         * Sets the value of ServiceId
         * @param value ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
         * @return {@code this}
         */
        public Builder withServiceId(final java.lang.String value) {
            this._serviceId = java.util.Objects.requireNonNull(value, "serviceId is required");
            return this;
        }
        /**
         * Sets the value of ServiceId
         * @param value ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
         * @return {@code this}
         */
        public Builder withServiceId(final software.amazon.awscdk.CloudFormationToken value) {
            this._serviceId = java.util.Objects.requireNonNull(value, "serviceId is required");
            return this;
        }
        /**
         * Sets the value of AllowedPrincipals
         * @param value ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
         * @return {@code this}
         */
        public Builder withAllowedPrincipals(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._allowedPrincipals = value;
            return this;
        }
        /**
         * Sets the value of AllowedPrincipals
         * @param value ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
         * @return {@code this}
         */
        public Builder withAllowedPrincipals(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._allowedPrincipals = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VPCEndpointServicePermissionsResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public VPCEndpointServicePermissionsResourceProps build() {
            return new VPCEndpointServicePermissionsResourceProps() {
                private java.lang.Object $serviceId = java.util.Objects.requireNonNull(_serviceId, "serviceId is required");
                @javax.annotation.Nullable
                private java.lang.Object $allowedPrincipals = _allowedPrincipals;

                @Override
                public java.lang.Object getServiceId() {
                    return this.$serviceId;
                }

                @Override
                public void setServiceId(final java.lang.String value) {
                    this.$serviceId = java.util.Objects.requireNonNull(value, "serviceId is required");
                }

                @Override
                public void setServiceId(final software.amazon.awscdk.CloudFormationToken value) {
                    this.$serviceId = java.util.Objects.requireNonNull(value, "serviceId is required");
                }

                @Override
                public java.lang.Object getAllowedPrincipals() {
                    return this.$allowedPrincipals;
                }

                @Override
                public void setAllowedPrincipals(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$allowedPrincipals = value;
                }

                @Override
                public void setAllowedPrincipals(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$allowedPrincipals = value;
                }

            };
        }
    }

    /**
     * A proxy class which for javascript object literal which adhere to this interface.
     */
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.cloudformation.VPCEndpointServicePermissionsResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
         */
        @Override
        public java.lang.Object getServiceId() {
            return this.jsiiGet("serviceId", java.lang.Object.class);
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
         */
        @Override
        public void setServiceId(final java.lang.String value) {
            this.jsiiSet("serviceId", java.util.Objects.requireNonNull(value, "serviceId is required"));
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
         */
        @Override
        public void setServiceId(final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("serviceId", java.util.Objects.requireNonNull(value, "serviceId is required"));
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getAllowedPrincipals() {
            return this.jsiiGet("allowedPrincipals", java.lang.Object.class);
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
         */
        @Override
        public void setAllowedPrincipals(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("allowedPrincipals", value);
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
         */
        @Override
        public void setAllowedPrincipals(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("allowedPrincipals", value);
        }
    }
}

==> ec2-0.9.1-sources.jar: software/amazon/awscdk/services/ec2/cloudformation/VPCEndpointServicePermissionsResourceProps.java <==
package software.amazon.awscdk.services.ec2.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.5 (build 845cc48)", date = "2018-09-14T09:16:47.254Z")
public interface VPCEndpointServicePermissionsResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
     */
    java.lang.Object getServiceId();
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
     */
    void setServiceId(final java.lang.String value);
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
     */
    void setServiceId(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
     */
    java.lang.Object getAllowedPrincipals();
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
     */
    void setAllowedPrincipals(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
     */
    void setAllowedPrincipals(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link VPCEndpointServicePermissionsResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link VPCEndpointServicePermissionsResourceProps}
     */
    final class Builder {
        private java.lang.Object _serviceId;
        @javax.annotation.Nullable
        private java.lang.Object _allowedPrincipals;

        /**
         * Sets the value of ServiceId
         * @param value ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
         * @return {@code this}
         */
        public Builder withServiceId(final java.lang.String value) {
            this._serviceId = java.util.Objects.requireNonNull(value, "serviceId is required");
            return this;
        }
        /**
         * Sets the value of ServiceId
         * @param value ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
         * @return {@code this}
         */
        public Builder withServiceId(final software.amazon.awscdk.CloudFormationToken value) {
            this._serviceId = java.util.Objects.requireNonNull(value, "serviceId is required");
            return this;
        }
        /**
         * Sets the value of AllowedPrincipals
         * @param value ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
         * @return {@code this}
         */
        public Builder withAllowedPrincipals(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._allowedPrincipals = value;
            return this;
        }
        /**
         * Sets the value of AllowedPrincipals
         * @param value ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
         * @return {@code this}
         */
        public Builder withAllowedPrincipals(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._allowedPrincipals = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VPCEndpointServicePermissionsResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public VPCEndpointServicePermissionsResourceProps build() {
            return new VPCEndpointServicePermissionsResourceProps() {
                private java.lang.Object $serviceId = java.util.Objects.requireNonNull(_serviceId, "serviceId is required");
                @javax.annotation.Nullable
                private java.lang.Object $allowedPrincipals = _allowedPrincipals;

                @Override
                public java.lang.Object getServiceId() {
                    return this.$serviceId;
                }

                @Override
                public void setServiceId(final java.lang.String value) {
                    this.$serviceId = java.util.Objects.requireNonNull(value, "serviceId is required");
                }

                @Override
                public void setServiceId(final software.amazon.awscdk.CloudFormationToken value) {
                    this.$serviceId = java.util.Objects.requireNonNull(value, "serviceId is required");
                }

                @Override
                public java.lang.Object getAllowedPrincipals() {
                    return this.$allowedPrincipals;
                }

                @Override
                public void setAllowedPrincipals(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$allowedPrincipals = value;
                }

                @Override
                public void setAllowedPrincipals(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$allowedPrincipals = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.cloudformation.VPCEndpointServicePermissionsResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
         */
        @Override
        public java.lang.Object getServiceId() {
            return this.jsiiGet("serviceId", java.lang.Object.class);
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
         */
        @Override
        public void setServiceId(final java.lang.String value) {
            this.jsiiSet("serviceId", java.util.Objects.requireNonNull(value, "serviceId is required"));
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.ServiceId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-serviceid
         */
        @Override
        public void setServiceId(final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("serviceId", java.util.Objects.requireNonNull(value, "serviceId is required"));
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getAllowedPrincipals() {
            return this.jsiiGet("allowedPrincipals", java.lang.Object.class);
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
         */
        @Override
        public void setAllowedPrincipals(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("allowedPrincipals", value);
        }

        /**
         * ``AWS::EC2::VPCEndpointServicePermissions.AllowedPrincipals``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservicepermissions.html#cfn-ec2-vpcendpointservicepermissions-allowedprincipals
         */
        @Override
        public void setAllowedPrincipals(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("allowedPrincipals", value);
        }
    }
}
